#!/bin/bash

# Script to recursively bytecompile all .py files in a path.
# Adapted from brp-python-bytecompile from rpm-build.

# We do not attempt to configure the Python environment - it is assumed
# this will be done by the caller. We just use 'python' from the path.


bytecompile() {

  SRCPATH=$1

  # Figure out how deep we need to descend.
  depth=`(find "$SRCPATH" -type f -name "*.py" -print0 ; echo /) | \
    xargs -0 -n 1 dirname | sed 's,[^/],,g' | sort -u | tail -n 1 | wc -c`
  if [ -z "$depth" -o "$depth" -le "1" ]; then
    exit 0
  fi

  # Generate normal (.pyc) byte-compiled files.
  python -c 'import compileall, re, sys; sys.exit (not compileall.compile_dir("'"$SRCPATH"'", '"$depth"', "/", force=1, quiet=1))'
  if [ $? -ne 0 -a 0$errors_terminate -ne 0 ]; then
    # One or more of the files had a syntax error
    exit 1
  fi

  # Generate optimized (.pyo) byte-compiled files.
  python -O -c 'import compileall, re, sys; sys.exit(not compileall.compile_dir("'"$SRCPATH"'", '"$depth"', "/", force=1, quiet=1))'
  if [ $? -ne 0 -a 0$errors_terminate -ne 0 ]; then
    # One or more of the files had a syntax error
    exit 1
  fi

}

# Iterate over paths given on the command line
ERRORS_TERMINATE=1
for PARAM in "$@"; do
  case "$PARAM" in
    --no-fail-on-errors ) ERRORS_TERMINATE=0 ;;
    *                   ) bytecompile $PARAM ;;
  esac
done

