#!/usr/bin/env python
'''
Remove specified python source files from a tower installation.  Used by the
rpm and deb build process.
'''

import sys
import os

if __name__ == "__main__":
    if len(sys.argv) < 2:
        print("Usage: %s <path> [<path> [...]]" % sys.argv[0])
        sys.exit(1)

    for root_dir in sys.argv[1:]:
        for dname, dirs, files in os.walk(root_dir):
            for f in map(lambda fname: os.path.join(dname, fname), files):
                if not f.startswith(os.path.join(root_dir, 'awx')) and not f.startswith(os.path.join(root_dir, 'tower_license')):
                    #print('Skipping: %s' % f)
                    continue
                if f == os.path.join(root_dir, 'awx/settings/postprocess.py'):
                    print("Skipping %s" % f)
                    continue
                if f.startswith(os.path.join(root_dir, 'awx/lib/site-packages')) or \
                   f.startswith(os.path.join(root_dir, 'awx/lib/awx_display_callback')) or \
                   f.startswith(os.path.join(root_dir, 'awx/lib/isolated_callbacks')) or \
                   f.startswith(os.path.join(root_dir, 'awx/scripts')) or \
                   f.startswith(os.path.join(root_dir, 'awx/plugins')) or \
                   f.startswith(os.path.join(root_dir, 'awx/playbooks')) or \
                   f.startswith(os.path.join(root_dir, 'awx/main/tests/data')):
                    #print('Skipping: %s' % f)
                    continue
                # Django 1.7+ does not support migrations in .pyc files, so keep
                # .py files: https://code.djangoproject.com/ticket/23406
                if f.startswith(os.path.join(root_dir, 'awx/main/migrations')) or \
                   f.startswith(os.path.join(root_dir, 'awx/sso/migrations')) or \
                   f.startswith(os.path.join(root_dir, 'awx/conf/migrations')):
                    continue
                if f.endswith('.py'):
                    print('Removing %s' % f)
                    os.unlink(f)
